/**
 * <p>Represents the data structure of a method's request or response payload.</p> <div class="remarks"> <p>A request model defines the data structure of the client-supplied request payload. A response model defines the data structure of the response payload returned by the back end. Although not required, models are useful for mapping payloads between the front end and back end.</p> <p>A model is used for generating an API's SDK, validating the input request body, and creating a skeletal mapping template.</p> </div> <div class="seeAlso"> <a>Method</a>, <a>MethodResponse</a>, <a href="https://docs.aws.amazon.com/apigateway/latest/developerguide/models-mappings.html">Models and Mappings</a> </div>
 */
export interface _Model {
    /**
     * <p>The identifier for the model resource.</p>
     */
    id?: string;
    /**
     * <p>The name of the model. Must be an alphanumeric string.</p>
     */
    name?: string;
    /**
     * <p>The description of the model.</p>
     */
    description?: string;
    /**
     * <p>The schema for the model. For <code>application/json</code> models, this should be <a href="https://tools.ietf.org/html/draft-zyp-json-schema-04" target="_blank">JSON schema draft 4</a> model. Do not include "\\*\/" characters in the description of any properties because such "\\*\/" characters may be interpreted as the closing marker for comments in some languages, such as Java or JavaScript, causing the installation of your API's SDK generated by API Gateway to fail.</p>
     */
    schema?: string;
    /**
     * <p>The content-type for the model.</p>
     */
    contentType?: string;
}
export declare type _UnmarshalledModel = _Model;
